Module encoding

Module encoding 

Sortable binary encoding for values and datom key components.

Enums

DecodeError
Decoding failure.

Traits

Encodable
Trait for types with Corium sortable encodings.

Functions

decode_entity_id
Decodes one fixed-width entity-id component.
decode_u64
Decodes one fixed-width unsigned integer component.
decode_value
Decodes one complete value and returns the value plus bytes consumed.
encode_value
Encodes a value into a fresh vector.