pub struct KeywordInterner { /* private fields */ }Expand description
Deterministic keyword interner for tests and bootstrap metadata.
Implementations
Sourceimpl KeywordInterner
impl KeywordInterner
Sourcepub fn intern(&mut self, keyword: Keyword) -> KwId
pub fn intern(&mut self, keyword: Keyword) -> KwId
Interns a keyword, returning the stable id assigned by this interner.
Sourcepub fn get(&self, keyword: &Keyword) -> Option<KwId>
pub fn get(&self, keyword: &Keyword) -> Option<KwId>
Looks up an already interned keyword without interning it.