Sortable binary encoding for values and datom key components.
Enums
- Decode
Error - Decoding failure.
Traits
- Encodable
- Trait for types with Corium sortable encodings.
Functions
- decode_
entity_ id - Decodes one fixed-width entity-id component.
- decode_
u64 - Decodes one fixed-width unsigned integer component.
- decode_
value - Decodes one complete value and returns the value plus bytes consumed.
- encode_
value - Encodes a value into a fresh vector.