Module ids

Module ids 

Entity, transaction, attribute, keyword, and partition identifiers.

Structs

EntityId
A Datomic-style entity id: 22-bit partition plus 42-bit sequence.

Enums

Partition
Built-in partitions.

Constants

SEQUENCE_BITS
Number of low bits reserved for the sequence within a partition.

Type Aliases

AttrId
Attribute ids are entity ids in the database partition.
KwId
Interned keyword id.
PartitionId
A raw partition id stored in the high bits of an entity id.
TxId
Transaction ids are entity ids in the transaction partition.